Calculate geo_extent_bounding_box_m2 for the dataset_summary table
calc_geo_extent_bounding_box_m2(west, east, north, south)(numeric) Area of study site in meters squared.
(numeric) West longitude in decimal degrees and negative if west of the prime meridian.
(numeric) East longitude in decimal degrees and negative if west of the prime meridian.
(numeric) North latitude in decimal degrees and negative if south of the equator.
(numeric) South latitude in decimal degrees and negative if south of the equator.